#
# spec file for package nagios
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           nagios
Version:        3.5.1
Release:        2.3
Summary:        The Nagios Network Monitor
License:        GPL-2.0+
Group:          System/Monitoring
Url:            http://www.nagios.org/
Source0:        %{name}-%{version}.tar.bz2
Source1:        rc%{name}
Source3:        %{name}.sysconfig
Source4:        suse.de-nagios
Source5:        nagios.8
Source6:        nagiosstats.8
Source7:        nagios-htpasswd.users
#
Source10:       %{name}-README.SuSE
Source11:       %{name}-html-pages.tar.bz2
Source12:       %{name}-3.0.6-docs.tar.bz2
Source20:       %{name}-rpmlintrc
# PATCH-FIX-UPSTREAM Fixes the output of spurious $ signs in commandoutput (deb#480001)
Patch2:         nagios-fix_spurious_dollar_signs_added_to_command_lines.patch
# PATCH-FIX-UPSTREAM unescape hex characters in CGI input - avoid addional '+'
Patch3:         nagios-fix_encoding_trends.cgi.patch
# PATCH-FIX-OPENSUSE openSUSE uses a special location for p1.pl
Patch10:        nagios-p1.pl-location.patch
# PATCH-FIX-OPENSUSE disable Nagios online update checks for distributed packages
Patch11:        nagios-disable_phone_home.patch
# PATCH-FIX-UPSTREAM fix CVE-2013-2214
Patch12:        nagios-CVE-2013-2214.patch
BuildRequires:  apache2-devel
BuildRequires:  freetype2-devel
BuildRequires:  gd-devel
BuildRequires:  iputils
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  mailx
BuildRequires:  nagios-rpm-macros
BuildRequires:  net-tools
BuildRequires:  openssl-devel
BuildRequires:  pcre-devel
BuildRequires:  zlib-devel
Requires(pre):  %fillup_prereq
Requires(pre):  %insserv_prereq
Requires(pre):  /bin/logger
Requires(pre):  coreutils
Requires(pre):  grep
Requires(pre):  pwdutils
Requires(pre):  sed
Provides:       monitoring_daemon
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} < 1010
BuildRequires:  XFree86-devel
BuildRequires:  XFree86-libs
BuildRequires:  libapr0
Requires:       cron
%else
BuildRequires:  xorg-x11-devel
BuildRequires:  pkgconfig(apr-util-1)
Recommends:     %{name}-www
Recommends:     cron
# this package contains shared tools with icinga
Recommends:     monitoring-tools
# we enable nagios embedded perl, but if people disable it...
Recommends:     perl = %{perl_version}
# as long as it is enabled we need the following requires
%{?libperl_requires}
%endif
Recommends:     icinga-monitoring-tools
%if 0%{?suse_version} > 1020
Recommends:     %{name}-plugins
%else
Requires:       %{name}-plugins
%endif
Requires:       mailx
%define         nslockfile_dir /var/run/%{name}
%define         nslockfile %nslockfile_dir/%{name}.pid
%define         apache2_sysconfdir %(/usr/sbin/apxs2 -q SYSCONFDIR)/conf.d
# Macro that print mesages to syslog at package (un)install time
%define         nnmmsg logger -t %{name}/rpm

%description
Nagios is a program that will monitor hosts and services on your
network. It has the ability to email or page you when a problem arises
and when a problem is resolved. Nagios is written in C and is designed
to run under Linux (and some other *NIX variants) as a background
process, intermittently running checks on various services that you
specify.

The actual service checks are performed by separate "plugin" programs
which return the status of the checks to Nagios. The plugins are
available at http://sourceforge.net/projects/nagiosplug

This package provides core programs for Nagios. The web interface,
documentation, and development files are built as separate packages

%package www
Summary:        Provides the HTML and CGI files for the Nagios web interface
Group:          System/Monitoring
Requires(pre):  /bin/logger
Requires(pre):  apache2
Requires(pre):  coreutils
Requires(pre):  gawk
Requires(pre):  grep
Requires(pre):  pwdutils
Requires(pre):  sed
Requires:       %{name} = %{version}
Requires:       gd
Requires:       mod_php_any
Requires:       php
Provides:       monitoring_webfrontend

%description www
Nagios is a program that will monitor hosts and services on your
network. It has the ability to email or page you when a problem arises
and when a problem is resolved. Nagios is written in C and is designed
to run under Linux (and some other *NIX variants) as a background
process, intermittently running checks on various services that you
specify.

Several CGI programs are included with Nagios in order to allow you to
view the current service status, problem history, notification history,
and log file via the web. This package provides the HTML and CGI files
for the Nagios web interface. In addition, HTML documentation is
included in this package.

%package www-dch
Summary:        HTML and CGI files that do not call home
Group:          System/Monitoring
Requires:       %{name}-www = %{version}

%description www-dch
Several CGI programs are included with Nagios in order to allow you to
view the current service status, problem history, notification history,
and log file via the web.

Since Version 3.1, some of those CGI files and the Nagios process itself
try to detect the latest version and fetching news feeds from the upstream
server www.nagios.org.

This additional package provides simply HTML files that do not "call
home" and also allow to run the web interface without PHP support.

There is also an offline version of the documentation included in this
package.

Please enable the flag "NAGIOSDCH" in the apache configuration.
Note: The HTML pages use 'side' and 'main' and frame targets.

%package devel
Summary:        Development files for Nagios
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       gcc

%description devel
Nagios is a program that will monitor hosts and services on your
network. It has the ability to email or page you when a problem arises
and when a problem is resolved. Nagios is written in C and is designed
to run under Linux (and some other *NIX variants) as a background
process, intermittently running checks on various services that you
specify.

This package provides include files that Nagios-related applications
may compile against.

%prep
%setup -q -n %{name}
%patch2 -p0
%patch3 -p0
%patch10 -p0
%patch11 -p0
%patch12 -p1
find -name ".gitignore" | xargs rm
# fix p1.pl [dos]
perl -p -i -e 's|\r\n|\n|' contrib/p1.pl
# fix file permissions
chmod -x Changelog LEGAL LICENSE README

%build
# if the following command fails, then apache dependencies are not met
/usr/sbin/apxs2 -q DATADIR >/dev/null
%configure \
	--prefix=%{_prefix} \
	--exec-prefix=%{_sbindir} \
	--bindir=%{_sbindir} \
	--sbindir=%{nagios_cgidir} \
	--libexecdir=%{nagios_plugindir} \
	--datadir=%{nagios_datadir} \
	--sysconfdir=%{nagios_sysconfdir} \
	--with-init-dir=%{_sysconfdir}/init.d \
	--localstatedir=%{nagios_localstatedir} \
	--with-cgiurl=/%{name}/cgi-bin \
	--with-htmurl=/%{name} \
	--with-httpd-conf=%{apache2_sysconfdir} \
	--with-checkresult-dir=%{nagios_spooldir} \
	--with-lockfile=%{nslockfile} \
	--with-nagios-user=%{nagios_user} \
	--with-nagios-group=%{nagios_group} \
	--with-command-user=%{nagios_command_user} \
	--with-command-group=%{nagios_command_group} \
	--with-gd-lib=%{_libdir} \
	--with-gd-inc=%{_includedir} \
	--with-template-objects \
	--with-template-extinfo \
	--with-perlcache \
	--enable-event-broker \
	--enable-embedded-perl
#
# /usr/bin/p1.pl is not a good place for a perl-_module_!
#
sed -i 's#@p1pldir@#%{nagios_libdir}#g' Makefile include/locations.h sample-config/nagios.cfg
#
# fix p1.pl debug-path
#
sed -i 's#/usr/local/nagios/var/#/var/log/%{name}/#g' p1.pl
# make rpmlint happy: add shebang to p1.pl
echo "#!/usr/bin/perl" > p1.pl.new
cat p1.pl >> p1.pl.new
mv p1.pl.new p1.pl
#
# make daemonchk.cgi and event handlers
#
make %{?_smp_mflags} all
make %{?_smp_mflags} -C contrib
pushd contrib/eventhandlers 1>/dev/null
for f in `find . -type f` ; do
    F=`mktemp temp.XXXXXX`
    sed "s=/usr/local/nagios/var/rw/=%{nagios_spooldir}/=; \
         s=NscaBin\=\"/usr/local/nagios/libexec/send_nsca\"=NscaBin\=/usr/bin/send_nsca=; \
         s=/usr/local/nagios/libexec/eventhandlers/=%{nagios_eventhandlerdir}/=; \
         s=/usr/local/nagios/libexec/=%{nagios_plugindir}/=; \
         s=/usr/local/nagios/etc/=%{nagios_sysconfdir}/=; \
         s=/usr/local/nagios/test/var=%{nagios_logdir}/=" ${f} > ${F}

    mv ${F} ${f}
done
popd 1>/dev/null

%install
mkdir -p %{buildroot}/%{nagios_logdir}/archives
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%apache2_sysconfdir/
mkdir -p %{buildroot}%nslockfile_dir
make install install-commandmode install-config install-webconf install-classicui\
    DESTDIR=%{buildroot} \
    INSTALL_OPTS="" \
    COMMAND_OPTS="" \
	CGICFGDIR="%{nagios_sysconfdir}" \
    INIT_OPTS=""
make install -C contrib \
    DESTDIR=%{buildroot} \
    INSTALL_OPTS=""
# install event handlers
install -d -m0755 %{buildroot}/%{nagios_eventhandlerdir}
cp -afpv contrib/eventhandlers/* %{buildroot}%{nagios_eventhandlerdir}/
find %{buildroot}%{nagios_eventhandlerdir}/ -type f -exec chmod +x {} \;
# install directory for event brokers like ndoutils
install -d -m0755 %{buildroot}%{nagios_localstatedir}/brokers
# install headers for development package
install -d -m0755 %{buildroot}%{_includedir}/%{name}/
pushd include
for file in *.h; do
    if test "x${file}" != "xconfig.h" -a "x${file}" != "xsnprintf.h" -a "x${file}" != "xcgiutils.h" ; then
        install -m 644 $file %{buildroot}%{_includedir}/%{name}/
    fi;
done
popd
#
# cleanup sample-conf dir for including in docdir
#
find sample-config/ -name "*.in" -exec rm {} \;
find sample-config/ -name "*.in.orig" -exec rm {} \;
sed -e 's|command_file=.*|command_file=%{nagios_command_file}|g' \
    -e 's|log_file=/var/lib/nagios/nagios.log|log_file=%{nagios_logdir}/nagios.log|g' \
    -e 's|log_archive_path=/var/lib/nagios/archives|log_archive_path=%{nagios_logdir}/archives|g' \
    -e 's|^lock_file=.*|lock_file=%nslockfile|g' \
    %{buildroot}/%{nagios_sysconfdir}/nagios.cfg > %{buildroot}%{_sysconfdir}/%{name}/nagios.cfg.tmp
mv %{buildroot}/%{nagios_sysconfdir}/nagios.cfg.tmp %{buildroot}%{_sysconfdir}/%{name}/nagios.cfg
#
# install SuSE specials
#
# README.SuSE file
sed -e 's@DATADIR@%{_datadir}/%{name}@g' -e 's@SYSCONFDIR@%{nagios_sysconfdir}@g' %{SOURCE10} > %_builddir/%{name}/README.SuSE
# init-script
install -D -m 0755 %{SOURCE1} %{buildroot}%{_sysconfdir}/init.d/%{name}
ln -sf ../../etc/init.d/%{name} %{buildroot}%{_sbindir}/rc%{name}
# sysconfig script
install -D -m 0644 %{SOURCE3} %{buildroot}%{_localstatedir}/adm/fillup-templates/sysconfig.%{name}
# install cronjob (gzip' the logfiles)
install -D -m 0755 %{SOURCE4} %{buildroot}%{_sysconfdir}/cron.weekly/%{name}
# install htpasswd file
install -m 0640 %{SOURCE7} %{buildroot}%{_sysconfdir}/%{name}/htpasswd.users
# important ghost files
touch %{buildroot}%{nagios_state_retention_file}
touch %{buildroot}%{nagios_status_file}
touch %{buildroot}%{nagios_logdir}/config.err
touch %{buildroot}%{nslockfile}
# install manpages
install -Dm644 %{SOURCE5} %{buildroot}%{_mandir}/man8/%{name}.8
install -Dm644 %{SOURCE6} %{buildroot}%{_mandir}/man8/nagiostats.8
# fixing permissions the dirty way....
for file in "README sample-config/README sample-config/template-object/README"; do
       chmod 644 $RPM_BUILD_DIR/%{name}/$file
done
# we use nagios_spooldir for this
test -d %{buildroot}%{nagios_localstatedir}/rw && rmdir %{buildroot}%{nagios_localstatedir}/rw
# install plain html files to allow users to use Nagios without internet connection
# and without PHP at all
pushd %{buildroot}%{nagios_datadir} >/dev/null
tar -xf %{SOURCE11}
tar -xf %{SOURCE12}
sed -i "s|Version 3.4.3|Version %{version}|g; \
		s|version=3.4.3|version=%{version}|g" main.html
# jip: ugly at the moment
#LINES=$(echo $(wc -l %%{buildroot}%%{apache2_sysconfdir}/%%{name}.conf | awk '" " { print $1}')-2 | bc)
LINES=40
head -n $LINES %{buildroot}%{apache2_sysconfdir}/%{name}.conf > %{buildroot}%{apache2_sysconfdir}/%{name}.conf.in
cat >> %{buildroot}%{apache2_sysconfdir}/%{name}.conf.in << EOF
    <IfDefine KOHANA2>
      DirectoryIndex index.html index.php
    </IfDefine>
</Directory>
EOF
mv -f %{buildroot}%{apache2_sysconfdir}/%{name}.conf.in %{buildroot}%{apache2_sysconfdir}/%{name}.conf
popd >/dev/null
# delete monitoring-tools because they are provided by monitoring-tools
rm -f %{buildroot}/%{_sbindir}/convertcfg
rm -f %{buildroot}/%{_sbindir}/mini_epn
rm -f %{buildroot}/%{_sbindir}/new_mini_epn

%clean
rm -rf %{buildroot}

%pre
# Create user and group on the system if necessary
%nagios_user_group_add
%nagios_command_user_group_add

# update?
if [ ${1:-0} -gt 1 ]; then
  # in the past, group www was used as nagios_command_group - now we use the default: nagcmd
  if id -Gn %{nagios_user} 2>/dev/null | grep -q %{nagios_command_group} >/dev/null 2>&1 ; then
    : # %%{nagios_user} is already in %%nagios_command_group group
  else
    # Add %%{nagios_user} to %%nagios_command_group.
    %if 0%{?suse_version} > 1220
      usermod -a -G %{nagios_command_group} %{nagios_user}
    %else
      groupmod -A %{nagios_user} %{nagios_command_group} 2>/dev/null
    %endif
    %{nnmmsg} "Added %{nagios_user} to %{nagios_command_group}"
  fi
fi

%post
# Update ?
if [ ${1:-0} -gt 1 ]; then
 if [ -f '%{nagios_sysconfdir}/nagios.cfg' ]; then
  DATE=$(date "+%Y-%m-%d-%H:%M")
  TMPFILE=$(mktemp /tmp/%{name}-XXXXXX)
  NAGIOS_CFG='%{nagios_sysconfdir}/nagios.cfg'
  cp -f $NAGIOS_CFG ${NAGIOS_CFG}_${DATE}
  if ! grep -q ^lock_file=%{nslockfile} "$NAGIOS_CFG" ; then
        echo "- updating pid lock_file= to %{nslockfile} in $NAGIOS_CFG" >> $TMPFILE
        sed -i "s@^lock_file=.*@lock_file=%{nslockfile}@" "$NAGIOS_CFG"
  fi
  if grep -q ^service_reaper_frequency "$NAGIOS_CFG" ; then
        echo "- renaming service_reaper_frequency to check_result_reaper_frequency in $NAGIOS_CFG" >> $TMPFILE
        sed -i "s@service_reaper_frequency@check_result_reaper_frequency@" "$NAGIOS_CFG"
  fi
  if grep -q ^aggregate_status_updates "$NAGIOS_CFG" ; then
        echo "- aggregate_status_updates option has been removed from $NAGIOS_CFG" >> $TMPFILE
        sed -i "s@^aggregate_status_updates@# aggregate_status_updates@" "$NAGIOS_CFG"
  fi
  if grep -q ^downtime_file "$NAGIOS_CFG" ; then
        set -- $(grep ^downtime_file "$NAGIOS_CFG" | sed 's@=@ @')
        shift
        file=$(echo $*)
        if [ -n "$file" ]; then
            if [ -f "$file" ]; then
                set -- $(grep ^state_retention_file "$NAGIOS_CFG" | sed 's@=@ @')
                shift
                state_retention_file=$(echo $*)
                echo "- adding the content of of $file to $state_retention_file" >> $TMPFILE
                cat "$file" >> "$state_retention_file"
            fi
        fi
        echo "- removing downtime_file variable (no longer supported) in $NAGIOS_CFG" >> $TMPFILE
        sed -i "s@^downtime_file@# downtime_file@" "$NAGIOS_CFG"
  fi
  if grep -q ^comment_file "$NAGIOS_CFG" ; then
        set -- $(grep ^comment_file "$NAGIOS_CFG" | sed 's@=@ @')
        shift
        file=$(echo $*)
        if [ -n "$file" ]; then
            if [ -f "$file" ]; then
                echo "- adding the content of $file to $state_retention_file" >> $TMPFILE
                cat "$file" >> "$state_retention_file"
            fi
        fi
        echo "- removing comment_file variable (no longer supported) in $NAGIOS_CFG" >> $TMPFILE
        sed -i "s@^comment_file@# comment_file@" "$NAGIOS_CFG"
  fi
  #{nnmmsg} $(cat $TMPFILE)
  rm $TMPFILE
 fi
else
  # First installation: create an alias for the default nagiosadmin user
  if [ -r etc/aliases ]; then
    if ! grep -q "^nagiosadmin:" etc/aliases; then
        echo -e "nagiosadmin:\troot" >> etc/aliases
	    %{nnmmsg} "Added alias for user nagiosadmin to /etc/aliases"
        if [ -x usr/bin/newaliases ]; then
            usr/bin/newaliases &>/dev/null || true
        fi
    fi
  fi
fi
%{fillup_and_insserv nagios}

%preun
%stop_on_removal %{name}

%postun
%restart_on_update %{name}
%{insserv_cleanup}

%post www
wwwusr=%{nagios_command_user}
if [ -f etc/apache2/uid.conf ]; then
    # If apache is installed, and we can find the apache user, set a shell var
    wwwusr=$(awk '/^[ \t]*User[ \t]+[a-zA-Z0-9]+/ {print $2}' etc/apache2/uid.conf)
fi
# if apache user is not in nagios_command_group, add it
if id -Gn $wwwusr 2>/dev/null | grep -q %{nagios_command_group} >/dev/null 2>&1 ; then
    : # $wwwusr (default: %%nagios_command_user) is already in Nagios cmd group
else
    # modify apache user, adding it to nagios_command_group
  %if 0%{?suse_version} > 1220
    usermod -a -G %{nagios_command_group} $wwwusr
  %else
    groupmod -A $wwwusr %{nagios_command_group} 2>/dev/null
  %endif
  %{nnmmsg} "User $wwwusr added to group %{nagios_command_group} so sending commands to Nagios from the CGI is possible."
fi
# Update ?
if [ ${1:-0} -eq 1 ]; then
	if [ -x %{_sbindir}/a2enmod ]; then
		# enable authentification in apache config
		%{_sbindir}/a2enmod authn_file >/dev/null
        %{_sbindir}/a2enmod auth_basic >/dev/null
        %{_sbindir}/a2enmod authz_user >/dev/null
		# enable php5 in apache config
		%{_sbindir}/a2enmod php5
	fi
fi
%restart_on_update apache2

%post www-dch
# Update ?
if [ ${1:-0} -eq 1 ]; then
    if [ -x %{_sbindir}/a2enflag ]; then
		# enable NAGIOSDCH flag in apache configuration
		%{_sbindir}/a2enflag NAGIOSDCH >/dev/null
	fi
fi
%restart_on_update apache2

%preun www
%restart_on_update apache2

%files
%defattr(0644,root,root,0755)
%doc Changelog LEGAL LICENSE README README.SuSE sample-config/
%dir %{nagios_libdir}
%dir %{nagios_plugindir}
%dir %{nagios_eventhandlerdir}
%exclude %{nagios_cgidir}/*
%{_mandir}/man8/%{name}*
%{_sbindir}/rc%{name}
%{_localstatedir}/adm/fillup-templates/sysconfig.%{name}
%attr(0755,root,root) %{_sysconfdir}/init.d/%{name}
%attr(0755,root,root) %{_sysconfdir}/cron.weekly/*
%attr(0755,root,root) %{nagios_eventhandlerdir}/*
%config(noreplace) %{nagios_sysconfdir}/*.cfg
%config(noreplace) %{nagios_sysconfdir}/objects/*.cfg
%ghost %config(missingok,noreplace) %{nagios_logdir}/config.err
# directories with special handling:
%attr(0755,root,%{nagios_command_group})           %dir %{nagios_sysconfdir}
%attr(0755,root,%{nagios_command_group})           %dir %{nagios_sysconfdir}/objects
%attr(0775,%{nagios_user},%{nagios_command_group}) %dir %{nagios_spooldir}
%attr(0775,%{nagios_user},%{nagios_command_group}) %dir %{nagios_localstatedir}
%attr(0755,%{nagios_user},%{nagios_group})         %dir %{nagios_logdir}
%attr(0755,%{nagios_user},%{nagios_group})         %dir %{nagios_logdir}/archives
%ghost                                             %dir %{nslockfile_dir}
# files with special handling
%config(noreplace) %attr(0640,root,%{nagios_group}) %{nagios_sysconfdir}/resource.cfg
%attr(0755,root,root) %{nagios_libdir}/p1.pl
%attr(0644,%{nagios_user},%{nagios_group}) %verify(not md5 size mtime) %ghost %config(missingok,noreplace) %{nslockfile}
%attr(0600,%{nagios_user},%{nagios_group}) %verify(not md5 size mtime) %ghost %config(missingok,noreplace) %{nagios_state_retention_file}
%attr(0664,%{nagios_user},%{nagios_group}) %verify(not md5 size mtime) %ghost %config(missingok,noreplace) %{nagios_status_file}
%attr(0750,root,%{nagios_command_group}) %{_sbindir}/%{name}
%attr(0750,root,%{nagios_command_group}) %{_sbindir}/nagiostats

%files www
%defattr(0644,root,root,0755)
%dir %{nagios_cgidir}
%dir %{nagios_datadir}
%attr(0755,root,root) %{nagios_cgidir}/*
%{nagios_datadir}/*
%config(noreplace) %{apache2_sysconfdir}/%{name}.conf
%attr(0640,root,%nagios_command_group) %config(missingok,noreplace) %{_sysconfdir}/%{name}/htpasswd.users
%exclude %{nagios_datadir}/*.html
%exclude %{nagios_datadir}/docs/*

%files www-dch
%defattr(0644,root,root,0755)
%{nagios_datadir}/*.html
%{nagios_datadir}/docs/

%files devel
%defattr(644,root,root,0755)
%{_includedir}/%{name}/

%changelog
* Tue Sep 24 2013 lars@linux-schulserver.de
- cleanup file list
* Wed Sep 11 2013 lars@linux-schulserver.de
- Recommend monitoring-tools package for those who want to convert
  their (real old) nagios configuration (using the subpackage from
  icinga)
* Thu Sep  5 2013 mls@suse.de
- add libperl_requires, as we link against libperl and thus
  need a specific version of perl
* Fri Aug 30 2013 schneemann@b1-systems.de
- update to 3.5.1:
  + Added handler for SIGXFSZ signal (Eric Stanley)
  + Fixed bug #444: Nagios 3.5.0 problem with macro $ADMINEMAIL$ :
    @ is converted to %%40 after 2 nagios reload (Duplicate of bug #407)
  + Fixed bug #407: Reloading nagios config causes spaces in notifications
    to become plus signs (Alexey Dvoryanchikov)
  + Fixed bug #445: Adding triggered downtime for child hosts causes a
    SIGSEGV on restart/reload (Eric Stanley)
  + Fixed bug #375: Freshness expiration never reached and bug #427:
    freshness threshold doesn't work if it is set long
    (Scott Wilkerson, Eric Stanley)
  + Fixed bug #432: Downtime scheduled as "Nagios Process" and not
    the Users name (Sam Lansing, Eric Stanley)
* Fri Jul 26 2013 thardeck@suse.com
- added icinga-monitoring-tools as recommend and removed the duplicated nagios files
* Fri Jun 28 2013 lars@linux-schulserver.de
- added nagios-CVE-2013-2214.patch fixing unauthorized host/service
  views displayed in servicegroup view (bnc#827020)
* Thu Jun 27 2013 lars@linux-schulserver.de
- fix permission problem on /usr/lib/nagios/plugins introduced with
  one of the latest updates
* Sun Mar 17 2013 lars@linux-schulserver.de
- adapt static html pages to reflect the current version
* Sat Mar 16 2013 schneemann@b1-systems.de
- update to 3.5.0:
  + Fixed bug #403: The "configuration" page of the webui doesn't use
    entity encoding when displaying the "command expansion" item (Eric
    Stanley, Phil Randal)
  + Fixed bug #424: Nagios Core 3.4.4 seg fault (core dump) on restart
    after removing config for running service (Eric Stanley)
  + Updated CGI utility functions to support UTF-8 characters (Eric Stanley)
  + Fixed bug where selecting Command Expansion from Configuration CGI
    page would display commands instead (Eric Stanley)
  + Fixed bug #369: status.cgi crashes with segfault when there are german
    ulauts (äöüß) in the hostname or the servicename (Eric Stanley)
  + Fixed bug #418: Scheduled Downtime Notifications Resent On Nagios
    Restart/reload (Eric Stanley
* Wed Mar 13 2013 lars@linux-schulserver.de
- general update for 12.1, 12.2 and 12.3 for bnc#809180
* Thu Feb 14 2013 lars@linux-schulserver.de
- provide 'monitoring_daemon' in the init script to allow other
  init scripts to depend on it
* Sat Jan 12 2013 lars@linux-schulserver.de
- update to 3.4.4:
  + Fixed bug #408: service checks get duplicated on reload (Eric Stanley)
  + Added NULL pointer checks to CGI code. (Eric Stanley)
  + Fixed buffer overflow vulnerability in CGI code. Thanks to Neohapsis
    for finding this. (Eric Stanley)
- refreshed patches
* Wed Jan  9 2013 lars@linux-schulserver.de
- added new subpackage nagios-www-dch (don't call home):
  + add plain html pages to allow users to disable PHP and
    loading of external references
  + re-added documentation (no external link any more)
* Tue Jan  1 2013 lars@linux-schulserver.de
- use new rpm macros for basic user-/groupadd commands:
  %%%%nagios_user_group_add
  %%%%nagios_command_user_group_add
* Mon Dec 17 2012 lars@linux-schulserver.de
- update to 3.4.3:
  * Applied fix for pagination and sorting on status.cgi #381
    (Phil Randal)
  * Fixed issue where deleting a downtime could cause Nagios to crash
    (Eric Stanley)
  * Corrected logic so that end times for flexible downtimes are
    calculated from the downtime start rather than the current time
    in the case where Nagios is restarted (Eric Stanley)
  * Fixed issue introduced by fix for bug #124 where flexible
    downtimes are not taken into account on Nagios restart.
    (Scott Wilkerson, Eric Stanley)
  * Fixed bug #247: If a service reports no performance data, the
    perfdata log file has no line indicating the test.
    (omnikron@free.fr)
  * Fixed link for unhandled unreachable host problems on tactical
    overview page (Rudolf Cejka)
  * Fixed bug #345 with wild card searches not paging properly
    on status.cgi (Phil Randal)
  * Fixed bug #343 on status.cgi where Service Group Summary can
    potentially show wrong totals (Mark Ziesemer)
  * Fixed memory leaks on SIGHUP (Carlos Velasco)
- refreshed patches
- just require php not php5 to allow a switch to php53
- do not compress logfiles per default to allow searching via
  webinterface
- init script now uses daemonchk.cgi to check for status (if present)
* Mon Nov 26 2012 aeszter@gwdg.de
- Use usermod instead of groupmod when suse_version > 1220 due to
  pwdutils/shadow switch.
* Tue Nov 20 2012 dimstar@opensuse.org
- Fix useradd invocation: -o is useless without -u and newer
  versions of pwdutils/shadowutils fail on this now.
* Thu Oct 11 2012 lars@linux-schulserver.de
- add virtual provides 'monitoring_daemon' and
  'monitoring_webfrontend' to allow 3rd party packages to run also
  with compatible solutions like icinga
* Sun Jun 10 2012 lars@linux-schulserver.de
- remove checks.c-declare-temp_buffer.patch again as this is
  fixed with the latest version
- added manpages for {new,}mini_epn and convertcfg
* Sun Jun  3 2012 ro@suse.de
- update to 3.4.1
  * Double quotes in check_command definition break functionality
  (#332, reverts #86)
* Wed May 23 2012 lars@linux-schulserver.de
- run config check first before restart (init script)
- ignore subsys-unsupported rpmlint check as the init script just
  removes it
* Mon May  7 2012 schneemann@b1-systems.de
- update to 3.4.0
  * Use execv() to execute active check commands (#86 - Ton Voon, dnsmichi)
  * Added service_check_timeout_state configuration variable (Bill McGonigle)
  * Permanently remove sleep on run_event == FALSE in main loop (Max
    <perldork@webwizarddesign.com>)
  * Reduce notification load by moving notification viability check into
    notification list creation (Opsview Team)
  * Added code to apply allow_empty_hostgroup_assignment flag to host and
    service dependencies (Daniel Wittenberg)
  * Users can now see hostgroups and servicegroups that contain at least
    one host or service they are authorized for, instead of having to be
    authorized for them all (Ethan Galstad)
  * RSS feed boxes fallback if an error occurs (Ethan Galstad)
  * RSS feeds no longer block main page load (Mike Guthrie)
  FIXES
  * Fix $NOTIFICATIONRECIPIENTS$ macro to contain all contacts assigned to
    host|service, not only notified contacts (Bug #98 Matt Harrington)
  * Scheduled Downtime Notifications Resent On Nagios Restart/reload (Bug
    [#124] - ricardo)
  * NOTIFICATIONTYPE MACRO never became CUSTOM (Bug #168 - Alexey
    Dvoryanchikov)
  * Plugged minor memory leaks in notification logic
* Wed Dec  7 2011 chris@computersalat.de
- fix p1.pl
  * remove "^M" (antidos ;))
* Tue Nov  1 2011 lars@linux-schulserver.de
- skip fdupes call and ignore that we might save 4k on the disk
  => fixes bnc #721346
- fix file permissions in docudir
- use nagios-rpm-macros
* Fri Oct  7 2011 lars@linux-schulserver.de
- also check (and fix) the ownership of the directory where
  $status_file lives - Nagios uses this directory for temporary
  files
* Mon Aug  1 2011 schneemann@b1-systems.de
- update to 3.3.1
  FIXES
  * Fixes status.cgi when called with no parameters, where host should be
  set to all if none specified (Michael Friedrich)
  * Fixes possible validation error with empty hostgroups/servicegroups
  (Sven-Göran Bergh)
  * Performance-data handling and checking is now thread-safe so long as
  embedded perl is not used.
  * Children should no longer hang on mutex locks held in parent for
  localtime() (and similar) calls.
  * Debug logging is now properly serialized, using soft-locking with a
  timeout of 150 milliseconds to avoid multiple threads competing for the
  privilege to write debug info.
  * Fixed extraneous alerts for services when host is down
  * Fixed incorrect parsing of multi-line host check results (Jochen Bern)
  * Fixed bug with passive host checks being incorrectly sent to event
  brokers as active checks
  * Fixed bug where passive host check status updates were not being
  propagated to event brokers
* Tue Jul 26 2011 andrea.turrini@gmail.com
- fixed typos in nagios.spec
* Fri Jul  8 2011 lars@linux-schulserver.de
- removed setuid bit from /var/spool/nagios - configure the
  right permissions on service start instead
- use the right STDERR in the cron script
- cleanup files section
* Tue Jul  5 2011 lars@linux-schulserver.de
- integrated cron script from Daniel Kozar (bnc#701208)
* Mon Jul  4 2011 lars@linux-schulserver.de
- fixes in init script if check_external_commands are enabled
- added nagios-3.2.3-CVE-2011-1523.patch to fix
  CVE-2011-1523 (bnc#682966)
* Sun Mar 13 2011 lars@linux-schulserver.de
- install /var/spool/nagios with setgroup bit set, so all new files
  in this directory belong to the command group (maybe we should
  use a permissions file for this?)
* Wed Oct  6 2010 lars@linux-schulserver.de
- update to 3.2.3:
  + Fixes problem where disabling all active hosts/services was not
    taking effect
  + Fixes for compiler warnings (code cleanup by Stephen Gran)
  + Fixes for format errors in event handler logging (Guillaume Rousse)
  + Fixed incorrect info in sample nagios.cfg file for
    state_retention_file (Michael Friedrich)
  + Fixed broker_event_handler() to return ERR if data is NULL
    (Michael Friedrich)
- rebased all patches
- adapted nagios-disable_phone_home.patch
* Mon Sep 20 2010 schneemann@b1-systems.de
- removed unneeded filter "permissions-directory-setuid-bit" from
  nagios-rpmlintrc
* Tue Sep  7 2010 schneemann@b1-systems.de
- cleaned spec and sources, removed unused patches from source
* Wed Sep  1 2010 schneemann@b1-systems.de
- reworked phone-home patch
* Wed Sep  1 2010 schneemann@b1-systems.de
- Update to nagios 3.2.2, excerpt from changelog:
  FIXES
  * Fix for choosing next valid time on day of DST change when clocks go
  one hour backwards
  * Fix for nagios now erroring when "Error: Could not find any
  contactgroup matching..." displayed
  * Fix tap tests for Solaris 10 and newer versions of Test::Harness
  * Fix for notifications not being sent out when scheduled downtime is
  cancelled (Daniel Pouzzner)
  * Fix for first notification delay being calculated incorrectly, and
  notifications potentially going out early (Pawel Malachowski)
  * Fix for text of scheduling downtime of all services on a host (Holger
  Weiss)
  * Fix for services inheriting notification period from hosts if not
  defined (Gordon Messmer)
  * Fix for incorrect service states on host failures (bug #130 Petya Kohts)
  * Fix for incorrect service state attributes being set on host failures
  (bug #128 Petya Kohts)
  * Fix for non-scheduled hosts and services not being updated in NDOUtils
  * Fix for incorrect host state counts in status CGI when viewing
  servicegroups (bug #72)
  * Fix for new Splunk integration query parameters (bug #136)
  * Fix for extra field header in availability CSV export (bug #113)
  * Fix for macro processing code modifying input string (Jochen Bern)
  * Fix for event execution loop re-scheduling host checks instead of
  executing them if service checks are disabled (bug #152)
  * Fix for segfaults on Solaris (Torsten Huebler)
  * Fix for incorrect comment expiration times being passed to event
  broker (Mattieu Kermagot)
* Thu Jul 15 2010 lars@linux-schulserver.de
- back to the old file permissions (once again for clean
  nagios support)
- readded nonsense stuff again
- create/fix check_result_path if needed
* Fri Jul  9 2010 chris@computersalat.de
- fix file/dir perms
  o once again for centreon support
- spec mods
  o sort TAGS
  o added lost Authors (description)
  o macros
  o remove nonsense stuff
* Thu Jun 24 2010 lars@linux-schulserver.de
- rebase phone-home patch
* Tue Jun 22 2010 lars@linux-schulserver.de
- recommend nagios-plugins only to avoid buildcycles
* Fri Jun 18 2010 lars@linux-schulserver.de
- fix init script: touch files if they do not exist-
* Fri May 28 2010 lars@linux-schulserver.de
- disable patch8 - needs rebasing
- install PIDDIR if it's not /var/run to avoid owner problems
  during start
- always change ownership of standard files to the right values
* Mon May 24 2010 lars@linux-schulserver.de
- fix 'Schedule downtime for this host and all services' behavior
  (http://tracker.nagios.org/view.php?id=133)
- fix typos resulting in non used style declarations
  (http://tracker.nagios.org/view.php?id=150)
- fix deleting comments from the hashlist
  (http://tracker.nagios.org/view.php?id=80)
- rebase nagios-p1.pl-location.patch
- fix a handful compiler warnings
- do not allow nagios to phone home: disable online_update_checks
- fix command-group
- BuildRequire net-tools for enabling WAP
* Fri May 14 2010 lars@linux-schulserver.de
- check_verbose now always prints the resulting logfile - this
  allows to see the warnings
* Tue May 11 2010 lars@linux-schulserver.de
- ghost the pid directory
* Wed May  5 2010 lars@linux-schulserver.de
- fix broken files section
- init skript now handles /var/run on tmpfs
- small adaptions of init skript
- default pidfile now /var/run/nagios/nagios.pid
- add manpages from Debian package
- add Debian patches:
  + nagios-fix_forced_servicechecks.patch
  + nagios-fix_encoding_trends.cgi.patch
  + nagios-fix_spurious_dollar_signs_added_to_command_lines.patch
* Tue Apr  6 2010 chris@computersalat.de
- cleanup source
  o removed nagios-3.2.0
* Wed Mar 10 2010 lars@linux-schulserver.de
- update to 3.2.1:
  Enhancements:
  + Link to allow scheduling downtime for all services on a host
  + Speedup to CGIs when lots of comments or downtimes in status.dat file
  + Patch for new_mini_epn to allow for any command line length without
    breaking extra trailing or leading whitespace
  Fixes:
  + Fix for incorrect scheduling when time has gone back an hour
    (partial fix for 24x7)
  + Fix for logging test, which was not timezone aware
    (bug #0000077 - Allan Clark)
  + Fix for CSS validation of padding: X
  + Fix for documentation re: case-insensitive nature of custom
    variables (Marc Powell)
  + Fix for template configurations which use negated wildcards
    (Tim Wilde)
* Mon Nov 23 2009 cschneemann@suse.de
- changed path to send_nsca in the eventhandler script according
    to the path given in the nagios-nsca package. BNC #486937
* Fri Nov  6 2009 chris@computersalat.de
- added lost changes
  o Jun 24 2009
  o Jun 23 2009
- spec mods
  o removed changelog
  o added LEGAL to doc
  o simplify install of extra SOURCES
- added support for centreon
  o centreon is frontend GUI for nagios
  o changed perms/ownership in files section
* Fri Aug 21 2009 chris@computersalat.de
- cleanup spec
  o fixed header
  o sorted TAGS
- fixed deps
  o added missing Req nagios-plugins
* Fri Aug 14 2009 cschneemann@suse.de
- added Requires php and mod_php_any
* Thu Aug 13 2009 cschneemann@suse.de
- added ndo2db to Should-Start/Should-Stop in rcnagios
  changed permission of resource.cfg (needed by centreon)
    (Changes by chris@computersalat.de)
* Wed Aug 12 2009 cschneemann@suse.de
- update to 3.2.0:
  * Fix for read-only permissions bug in CGIs that caused problems viewing
  comments (bug #0000029)
  * Fix for incorrect CGI reports (availability, trends, etc.) when
  reporting period spans Daylight Savings Time (bug #0000046)
  * Fix for detection of truecolor support in GD library (Lars Hecking)
  * Reverted to use --datadir configure script option instead of the more
  recently introduced --datarootdir option
  * Status and retention files are now flushed/synced to disk to prevent
  incomplete information being displayed in CGIs
  * Fix for incorrect next service check time calculation when Nagios is
  reloaded with different timeperiod ranges
  * Updated Fedora quickstart guide to indicate PHP requirements
  * Known issue: Service checks that are defined with timeperiods that
  contain "exclude" directives are incorrectly re-scheduled.  Don't use
  these for now - we'll get this fixed for 3.4
* Wed Jun 24 2009 cschneemann@suse.de
- update to 3.1.2
  - fixes bug in host/service schduling logic that caused excessive
    CPU usage introduced with 3.1.0
* Tue Jun 23 2009 cschneemann@suse.de
- update to 3.1.1
  * New "important check command" flag for use in service templates, to
    aid configuration in distributed environments
  * Fix for nagios validation error when no services defined
  * Fix for stylesheet link
  * Fix for extinfo.cgi error message when cgi.cfg doesn't exist
  * Fix for notifications.cgi where Update button on right didn't retain
    host information when no host= was in query parameters
  * Fix for potential bug where a contactgroup with no members could cause
    parsing errors
  * Fix for W3 validation for history.cgi
  * Fix for W3 validation for extinfo.cgi
  * Fix for nagiostats to return non-zero with failures in MRTG mode
  * Added t/ directory for tests. Use make test to run. Requires perl on
    development server
  * Fix for duplicate event_id attributes in status and retention data
  * Fix for duplicate unlink() during check processing
  * Added missing check period column to host config display (CGI)
  * Fix for embedded Perl initialization under FreeBSD
  * Fix for incorrect re-initialization of mutext after program restart
  * Fix for incorrect weighting in host flap detection logic
  * Added libtap to distribution. Use ./configure --enable-libtap to compile
  * nagios.log permissions are now kept after log rotation
  * Fix for "Max concurrent service checks (X) has been reached" messages
  - will now push services 5 + random(10) seconds ahead for retry
  * Fix for removing old HTML files for web frontend that are now replaced
    with PHP equivalents (in dex/main/side.html)
  * Fix for incorrect service history link text in CGIs
  * Fix for useless code loop in netutils.c
  * Fix for potential divide by zero in event scheduling code
  * Fix for trailing backslash in plugin output causing memory corruption
    in CGIs
  * Fix for bug that could affect host/service scheduling during clock
    time skew or changes to time perod definitions between restarts
  * Leading whitespace from continuation lines in configuration files is
    now stripped out
  * Fix for bug where pipe (used by IPC) file descriptors get inherited by
    child processed (e.g. event handlers) (bug #0000026)
  * Fix for failure to daemonize - Nagios now bails (bug #0000011)
  * Fix for notifications about flapping starting not processed properly
    by retention data
  * Patch to add transparency to statusmap icons for truecolor images
  * Patch to add read-only permissions to extinfo CGI
  * Security fix for statuswml.cgi where arbitrary shell injection was
    possible
* Fri Mar 27 2009 cschneemann@suse.de
- added check_verbose to rcnagios to print the error messages
    directly instead of pointing to the error_log BNC #486912
* Tue Mar  3 2009 cschneemann@suse.de
- changed rcnagios to delete control characters from values
    BNC #480747
* Tue Dec  9 2008 cschneemann@suse.de
- update to 3.0.6:
  + Fix for CGI submission of external commands (writing newlines
    and submitting service comments)
  + Fix for Apache group membership in RPM spec file
  + Fix for improper notification propagation command processing
  + Better out-of-disk-space error handling when writing retention
    and status files
  + Disabled adaptive check and eventhandler commands for security
    reasons
  + Fix for reading output from system commands (event handlers,
    etc) that have timed out
  + Added wildcard host matching in CGIs
  + Fixes for playing audio alerts in CGIs
  + Fix for incorrect host status links in status CGI when viewing
    hostgroup summary
  + Added support for x509 cert authentication in the CGIs
* Mon Dec  1 2008 lrupp@suse.de
- don't fail if the host has problems to execute newaliases
* Mon Nov 10 2008 lrupp@suse.de
- update to 3.0.5:
  + Security fix for Cross Site Request Forgery (CSRF) bug reported
    by Tim Starling.
  + Sample audio files for CGIs removed from distribution
  + Fix for mutliline config file continuation bug
  + Minor sample config file fix
  + Added documentation on CGI security issues
- added permissions-directory-setuid-bit for /var/spool/nagios
* Tue Oct 28 2008 lrupp@suse.de
- use relative pathnames in %%%%post
* Fri Oct 17 2008 lrupp@suse.de
- update to 3.0.4:
  + Fix for properly terminating plugins when parent processes get
    killed (e.g. using 'killall nagios' with check_timeout plugins
    running)
  + Fix for event broker callback when service notifications are
    disabled
  + Fix for scheduling scheduling servicegroup downtime with
    'hosts too' option in CGIs
  + Fixes for bugs in sample event handlers - stop/start active
    service checks and enable notifications
  + Cosmetic fix for logging of notifications
  + Fix for host/service name encoding in CGIs (trends and
    availability reports, etc.)
* Mon Sep 15 2008 lrupp@suse.de
- be a bit more secure in %%post scripts
- fix ownership of resource file in init script
- enhance the README.SuSE a bit
- Recommend cron
* Mon Jul 21 2008 lrupp@suse.de
- fix fillup call
- update to 3.0.3:
  + Minor bug fixes in CGIs
  + Minor bug fix in navigation frame
  + Better error logging during fork() errors
  + Fixed bug in parsing host dependencies
  + Updated p1.pl to allow for 4KB lines in Perl plugin output
  + Fixed bug in command for disabling contact notifications
  + Fix for bugs in host and service orphan check logic
  + Fix for properly escaping macros containing URLs
  + Patches for possible XSS vulnerability in CGIs (CVE-2007-5803)
  + Changes to service check event broker logic (DNX patches)
  + Fixes for url encoding
  + Fix for debug logging of notifications
  + Segfault fix in history CGI
  + Typo fix in object config routines
* Thu May 29 2008 olh@suse.de
- fix missing return value in run_async_service_check (bnc#395203)
* Thu Apr 24 2008 olh@suse.de
- require mailx (bnc#383209)
* Tue Apr 22 2008 olh@suse.de
- fix cron logfile-check in /var/log/nagios/archives/ (bnc#381857)
* Thu Apr  3 2008 lrupp@suse.de
- update to 3.0.1:
  + Fixed bug in trends CGI with user not being authorized
    for hosts/services
  + Fixed bug in status CGI with page layout messing up when
    sounds enabled
* Thu Mar 13 2008 lrupp@suse.de
- update to 3.0 (final):
  + Faster program startup times (especially in large installs)
    with new object lookup code
  + Fix for special contact inheritance rules in
    host and service escalations
  + Fix for bug in processing $CONTACTADDRESSx$ macros
  + Documentation fixes
- Recommend perl
* Wed Mar  5 2008 lrupp@suse.de
- update to 3.0rc3:
  + New macros have been added
  + The old $NOTIFICATIONNUMBER$ macro has been deprecated in favor
    of new $HOSTNOTIFICATIONNUMBER$ and $SERVICENOTIFICATIONNUMBER$
    macros.
  + The $HOSTNOTES$ and $SERVICENOTES$ macros may now contain
    macros themselves
  + new 'enable_environment_macros' option, which allow to disable
    global macros for use in check, event handler, notification,
    and other commands on large installations
  + scheduled downtime entries are now stored in the status file
    and retention file, respectively
  + Current and retained comments are now stored in the status file
    and retention file, respectively
  + Acknowledgement comments that are marked as non-persistent are
    now only deleted when the acknowledgement is removed.
  + Comment and downtime IDs are now retained across program
    restarts and should be unique unless the retention data is
    deleted or ignored.
  + Added flap_detection_options directive to host and service
    definitions to allow you to specify what host/service states
    should be used by the flap detection logic
  + Added a new PROCESS_FILE external command to allow processing
    of external commands found in an eternal (regular) file.
  + Contact status information (last notification times,
    notifications enabled/disabled, etc.) is now saved in the
    status and retention files, although it is not processed
    by the CGIs.
  + check timeperiod for hosts and services can now be modified
    on-the-fly
  + Multiline plugin output is now supported for host and
    service checks
  + Nagios now checks for orphaned service checks by default.
  + Host checks are now run in parallel
  + Timeperiods were overdue for a major overhaul
  + Added event broker callbacks for adaptive programm and contact
    status data
  + ... (See ChangeLog for more details)
- Logfiles are stored in /var/log/nagios now
- Nagios uses own logrotation - but we bzip the old logfiles via
  weekly cronjob (Requires: bzip2)
- added sysconfig file for timeout and nice level
- overhaul the init script
- added a README.SuSE
- added rpmlintrc
- added config.err file as %%ghost
- use upstream macros for all steps during rpmbuild where possible
- adapt to work on all (open)SUSE distributions
- overhaul the patches
- cmdusr is now wwwrun and not nobody
- cmdgrp is now new group nagcmd and not www
- split out devel package
- enable event-broker
- use upstream apache config
- adapt the generated sample configurations so the work out of the
  box
- enable template-objects
- prepare and own the directory for event brokers
- include all sample configuration in docdir
- use fdupes
- create/update new groups/users in %%pre of the (sub-)package
- add the apache2 user to the nagcmd group in %%post of nagios-www
- restart apache2 if nagios-www changes
- own some %%ghost files with the correct permissions
* Fri Oct 26 2007 tsieden@suse.de
- update to nagios version 2.10
  * Added 'make install-webconf' command to install Apache web config file
  * Sample config files are now installed without a -sample extension
  * Fix for SIGTERMs being seen as SIGEXITs, non-logging of SIGTERMs/shutdowns
  * Minor fix for notification timeout log messages
  * Fix for not logging passive host check results
  * Minor bug fixes in CGIs
  * Fix for a segfault when processing passive host check results with empty output/perfdata
  * Fix for incorrect latency calculation for passive service checks
  * Bug fix with attempting to access an uninitalized mutex if external commands are disabled
  * Fix for keeping service checks in the event queue when active service checks are disabled globally
  * Fix for a potential cross site scripting vulnerability in the CGIs
  * Program version is now displayed in CGIs
- removed obsolete FAQ patch in html/docs dir
* Sun Sep 16 2007 cschneemann@suse.de
- added openssl-devel to BuildRequires to support SSL in check_http
* Sun Aug 12 2007 olh@suse.de
- move p1.pl to /usr/lib/nagios/p1.pl
  set 0755 permissions for executable files (157814)
* Wed May 16 2007 lrupp@suse.de
- build on older distributions:
  BuildRequires: libapr0 XFree86-devel XFree86-libs
* Fri May  4 2007 tsieden@suse.de
- update to nagios version 2.9
  * Fix for incorrect performance data file write/append mode options
  * Fix for current status of hosts with no host check command defined
  * SIGSEGV signals should now be logged again (broken in 2.8)
  * Configure script fix for no mail program found/installed on system
  * Configure script option bug fixes for cygwin and embedded perl
  * Command definitions and host/service plugin perfdata with HTML should now be escaped in CGIs
  * Patch for incorrect time down percentage in availability CGI
  * Updated init script to fix a race condition during restarts
* Mon Mar 12 2007 tsieden@suse.de
- update to nagios version 2.8
  * Bug fix for calculating notification interval with service escalations
  * Bug fix for using servicegroups in service dependency definitions
  * Bug fix for bad date format submission in command CGI
  * Possible segfault fix during restarts when daemon was performing host checks
  * Fix for missing check timeout in event broker calls
  * Fix for handling signals under NPTL
  * Added error messages for passive service checks that don't correspond to a defined service
* Fri Feb  9 2007 tsieden@suse.de
- update to nagios version 2.7
  * p1.pl now sets environment var (NAGIOS_PLUGIN) to indicate patch of plugin that is executing
  * Updated nagiostats with new MRTG vars for tracking buffer usage
  * Added sample MRTG config file
  * Minor patches to availability and status CGIs
  * Minor documentation updates
  * Fix for segfault during expiration or deletion of scheduled downtime
  * Fix for scheduling immediate service check through WAP interface
  * Fix for leading whitespace before comments in object config files
* Thu Feb  1 2007 olh@suse.de
- add quick-start.txt (#237372)
* Thu Feb  1 2007 olh@suse.de
- remove unneeded trailing slashes from Alias and Directory entries
  in nagios-http.conf
* Wed Jan 17 2007 olh@suse.de
- fix more comparison with string literal in avail.c
* Thu Jan 11 2007 olh@suse.de
- FATE #301512
* Thu Jan 11 2007 olh@suse.de
- fix typo in html docu, perdata.html -> perfdata.html
* Thu Jan 11 2007 olh@suse.de
- correct link to external FAQ website
* Thu Jan 11 2007 olh@suse.de
- correct Alias in nagios-httpd.conf
* Wed Jan 10 2007 olh@suse.de
- update the default example config to mail to nagios%%localhost
  instead to non-existant nagios-admin%%localhost
* Wed Jan 10 2007 olh@suse.de
- fix comparison with string literal (#232415)
* Mon Jan  8 2007 olh@suse.de
- move pid file to /var/run/nagios/ (#231169)
* Fri Dec  1 2006 tsieden@suse.de
- update to version 2.6
  * fix for unscheduled triggered downtime entries
  * fix for embedded audio in tac and status CGIs
  * fixed bug in nagiostats utility when reporting host/service check latency
  * misc code cleanups for compiler warnings
  * fixed error when reading empty (zero byte) config files
  * default is now to check for orphaned service checks (Francois Caen)
  * fixed bug with non-standard CGI config file location in status data (Carson Gaspar)
  * fixed bugs and simplified examples in sample config files (Mark Young)
  * removed obsolete patches which are included in upstream now
- fixed "empty PID file error" in init script
* Thu Nov 16 2006 tsieden@suse.de
- changed home dir to /var/lib/nagios (#221791)
* Tue Oct 17 2006 olh@suse.de
- fix uninitialized variable in run_global_service_event_handler (212892)
* Mon Sep 18 2006 olh@suse.de
- add a user/group nagios (#61908)
* Fri Sep  8 2006 olh@suse.de
- update to version 2.5
  disable sapmon patch for the time being
* Wed May 24 2006 schwab@suse.de
- Don't build as root.
- Don't strip binaries.
- Fix format string bug.
* Wed May  3 2006 stark@suse.de
- fixed possible buffer overflow in CGI scripts (#140494)
  (CVE-2006-2162)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan  9 2006 stark@suse.de
- fixed off-by-one overflow (#141124)
* Fri Nov 18 2005 stark@suse.de
- update to stable version 1.3
* Thu Oct  6 2005 stark@suse.de
- fixed autobuild warnings about printf format
* Sat May 14 2005 stark@suse.de
- fixed compiler errors about usage of uninitialized vars
* Sun Apr 24 2005 aj@suse.de
- Compile with GCC4.
* Mon Aug 30 2004 ro@suse.de
- removed apache1 traces
* Mon May  3 2004 stark@suse.de
- fix compiler-warnings
* Tue Feb  3 2004 stark@suse.de
- update to nagios 1.2
* Thu Sep 18 2003 stark@suse.de
- /usr/lib/nagios and /usr/lib/nagios/plugins are owned
  by root (#31100)
* Mon Sep  8 2003 stark@suse.de
- add apache2 config-files, require http_daemon
  and need apache2-devel-packages for build (#30157)
* Wed Aug 27 2003 ro@suse.de
- remove traceroute-lbl from neededforbuild
  traceroute from net-tools is used anyway
* Mon Aug 18 2003 stark@suse.de
- added activation meta-data to sysconfig (#28830)
* Fri Aug 15 2003 poeml@suse.de
- change cmdgrp from nogroup to www (the group apache now runs
  under) [#21782]
- implement try-restart correctly
* Thu Jul 31 2003 stark@suse.de
- use stop/restart macros
* Tue Jul 29 2003 aj@suse.de
- Fix chown invocation.
* Fri Jul 25 2003 stark@suse.de
- added bugfixes
* Thu Jun 12 2003 kukuk@suse.de
- Make sure plugin directory exist
* Thu Jun 12 2003 kukuk@suse.de
- Add nagios libdir to filelist
* Wed Jun  4 2003 stark@suse.de
- update to bugfix release 1.1
  * File descriptor leak in file-based performance routines
  * Timestamp fix for PostgreSQL 7.3
  * Minor bug fixes to cmd and history CGIs
  * Minor documentation fixes
* Mon Jan 13 2003 stark@suse.de
- added sysconfig-metadata (#22607)
* Mon Dec  2 2002 stark@suse.de
- adopted sapmoni.dif for gcc 3.3
* Mon Nov 25 2002 stark@suse.de
- update to 1.0 final
  * Minor bug fixes in CGIs
  * Minor doc updates
  * Bug fix for flex host downtime
  * Embedded perl bug fixe for arguments with spaces
  * Host escalation logic fix
* Tue Oct 15 2002 stark@suse.de
- running pre-flight configuration check always when
  starting nagios (#20916)
- added logrotate definitions for logfiles
- fixed embedded perl (#20916) (thanks to mls)
* Mon Sep 23 2002 stark@suse.de
- update to 1.0b6
  * Added wildcards and multiple hosts/hostgroups to host dependency
    and service dependency definitions
  * Added wildcard support for members directive in hostgroup
    definitions
  * Minor bug fixes and cleanups in CGIs
  * Minor cleanups in the core
  * New version of snprintf() included that supports %%f
  * Notification interval for escalations now defaults to
    non-escalated value
* Fri Aug 23 2002 stark@suse.de
- update to 1.0b5
  * Fixed memory leak related to processing of passive checks
  * Memory leak fixes in the CGIs
  * Minor interface changes to the status and TAC CGIs
  * Bug fix in the notification CGI
  * Added minimalistic sample object config file (minimal.cfg)
* Fri Aug 16 2002 stark@suse.de
- added PreReq (Bug #17938 #17939)
* Mon Aug 12 2002 stark@suse.de
- updated sapmoni patch to provide documentation
* Mon Aug 12 2002 mls@suse.de
- made it work with threaded perl-5.8
* Thu Aug  8 2002 stark@suse.de
- added patch to be able to use nagios-plugins-sap
* Sat Jul 27 2002 adrian@suse.de
- fix neededforbuild
* Fri Jul  5 2002 stark@suse.de
- update to 1.0b4
  * Address field in host definitions is now optional in
    template-based config format. Defaults to host name if not
    specified.
  * Fixed memory leak when processing passive checks
  * Added illegal_macro_output_chars variable to main config file
    to allow for stripping dangerous shell characters from plugin
    output
* Wed Jun 12 2002 stark@suse.de
- removed -devel subpackage and moved the file to main-package
* Mon Jun 10 2002 stark@suse.de
- update to 1.0b3
  * Bug fixes in template-based object code
  * Bug fix in tac CGI for counting host and service states
    properly
  * Default is now to check for external commands as often as
    possible
  * Ping syntax for WAP interface moved to CGI config file
  * Command file user/group defaults to Nagios user/group unless
    overridden with configure script options
  * Sample template-based object config file fixes
* Tue May 28 2002 stark@suse.de
- update to 1.0b2
  * Fixed bug with escaping strings for DB support
    (MySQL & PostgreSQL)
  * Several bug fixes in template-based object code
  * Multiple hostgroups supported in host and service escalations
  * Wildcard support in service, service escalation, and host
    escalation definitions
* Thu May 23 2002 stark@suse.de
- install config-file templates
* Wed May 22 2002 stark@suse.de
- initial version of Nagios (the successor of NetSaint)
